<?php
/**
 * @package Natalie WP
 */

add_action('widgets_init', 'natalie_wp_author_register');

function natalie_wp_author_register() {
    register_widget('natalie_Author_Widget');
}

class natalie_Author_Widget extends WP_Widget {

    public function __construct() {
        parent::__construct(
                'natalie_Author_Widget', esc_html__('Nathalie WP Author Box', 'natalie-wp'), array(
                'description' => esc_html__('Show Author Profile', 'natalie-wp')
                )
        );
    }

    /**
     * Helper function that holds widget fields
     * Array is used in update and form functions
     */
    private function widget_fields() {

        $fields = array(

            'natalie_widget_title' => array(
                'natalie_widgets_name' => 'natalie_widget_title',
                'natalie_widgets_title' => esc_html__('Title', 'natalie-wp'),
                'natalie_widgets_field_type' => 'text',
            ),

            'natalie_author_name' => array(
                'natalie_widgets_name' => 'natalie_author_name',
                'natalie_widgets_title' => esc_html__('Author Name', 'natalie-wp'),
                'natalie_widgets_field_type' => 'text',
            ),
            'natalie_author_desc' => array(
                'natalie_widgets_name' => 'natalie_author_desc',
                'natalie_widgets_title' => esc_html__('Author Description', 'natalie-wp'),
                'natalie_widgets_field_type' => 'textarea',
            ),
            'natalie_author_image' => array(
                'natalie_widgets_name' => 'natalie_author_image',
                'natalie_widgets_title' => esc_html__('Author Image', 'natalie-wp'),
                'natalie_widgets_field_type' => 'upload',
            ),
            'natalie_author_facebook' => array(
                'natalie_widgets_name' => 'natalie_author_facebook',
                'natalie_widgets_title' => esc_html__('Facebook Link', 'natalie-wp'),
                'natalie_widgets_field_type' => 'text',
            ),
            'natalie_author_twitter' => array(
                'natalie_widgets_name' => 'natalie_author_twitter',
                'natalie_widgets_title' => esc_html__('Twitter Link', 'natalie-wp'),
                'natalie_widgets_field_type' => 'text',
            ),
            'natalie_author_youtube' => array(
                'natalie_widgets_name' => 'natalie_author_youtube',
                'natalie_widgets_title' => esc_html__('Youtube Link', 'natalie-wp'),
                'natalie_widgets_field_type' => 'text',
            ),
            'natalie_author_instagram' => array(
                'natalie_widgets_name' => 'natalie_author_instagram',
                'natalie_widgets_title' => esc_html__('Instagram Link', 'natalie-wp'),
                'natalie_widgets_field_type' => 'text',
            ),
            'natalie_author_linkedin' => array(
                'natalie_widgets_name' => 'natalie_author_linkedin',
                'natalie_widgets_title' => esc_html__('LinkedIn Link', 'natalie-wp'),
                'natalie_widgets_field_type' => 'text',
            ),
        );

        return $fields;
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget($args, $instance) {
        extract($args);
        $natalie_widget_title = isset( $instance['natalie_widget_title'] ) ? $instance['natalie_widget_title'] : __( 'Recent Posts', 'natalie-wp' );
        $title = apply_filters( 'widget_title', $widget_name, $instance, $this->id_base );
        $natalie_author_name = apply_filters( 'widget_title', empty( $instance['natalie_author_name'] ) ? '' : $instance['natalie_author_name'], $instance, $this->id_base );       
        $natalie_author_desc = isset( $instance['natalie_author_desc'] ) ? $instance['natalie_author_desc'] : '' ;
        $natalie_author_image = isset( $instance['natalie_author_image'] ) ? $instance['natalie_author_image'] : '' ;
        $natalie_author_facebook = isset( $instance['natalie_author_facebook'] ) ? $instance['natalie_author_facebook'] : '' ;
        $natalie_author_twitter = isset( $instance['natalie_author_twitter'] ) ? $instance['natalie_author_twitter'] : '' ;
        $natalie_author_youtube = isset( $instance['natalie_author_youtube'] ) ? $instance['natalie_author_youtube'] : '' ;
        $natalie_author_instagram = isset( $instance['natalie_author_instagram'] ) ? $instance['natalie_author_instagram'] : '' ;
        $natalie_author_linkedin = isset( $instance['natalie_author_linkedin'] ) ? $instance['natalie_author_linkedin'] : '' ;
        echo $before_widget;
        ?>

<div class="widget widget-about-sidebar">
<?php if ( $natalie_widget_title ) :?>
    <div class="widget-title">
            <h2 class="text-center"><?php echo esc_html($natalie_widget_title);?></h2>
    </div>
    <?php endif;?>
    <div class="widget-about-img">
    <?php  if( $natalie_author_image ){ ?>
        <img class="rounded-circle img-fluid" src="<?php echo esc_url($natalie_author_image)?>" alt="<?php echo esc_html($natalie_author_name); ?>" width="150" height="100">
        <?php }?>
        <?php if($natalie_author_name){ ?>
        <div class="author-title"><?php echo esc_html($natalie_author_name); ?></div>
        <?php } ?>
    </div>

    <div class="widget-about-content">
        <?php if($natalie_author_desc){ ?>
        <p><?php echo esc_html($natalie_author_desc); ?></p>
        <?php } ?>

        <div class="widget-divider">
            <div class="blog-post-divider-top"></div>
            <div class="blog-post-divider-bottom"></div>
        </div>

        <div class="social-media-icons p-0 pb-4 text-center">
            <ul class="list-inline small mb-0 text-dark">
            <?php if( $natalie_author_facebook ){ ?>
                <li class="list-inline-item"><a class="reset-link-color" href="<?php echo esc_url( $natalie_author_facebook ); ?>"><i class="fab fa-facebook-f"></i></a></li>
                <?php } ?>
                <?php if( $natalie_author_twitter ){ ?>
                <li class="list-inline-item"><a class="reset-link-color" href="<?php echo esc_url( $natalie_author_twitter ); ?>"><i class="fab fa-twitter"></i></a></li>
                <?php } ?>
                <?php if( $natalie_author_instagram ){ ?>
                <li class="list-inline-item"><a class="reset-link-color" href="<?php echo esc_url( $natalie_author_instagram ); ?>"><i class="fab fa-instagram"></i></a></li>
                <?php } ?>
                <?php if( $natalie_author_linkedin ){ ?>
                <li class="list-inline-item"><a class="reset-link-color" href="<?php echo esc_url($natalie_author_linkedin)?>"><i class="fab fa-linkedin"></i></a></li>
                <?php } ?>
                <?php if( $natalie_author_youtube ){ ?>
                <li class="list-inline-item"><a class="reset-link-color" href="<?php echo esc_url( $natalie_author_youtube ); ?>"><i class="fab fa-youtube"></i></a></li>
                <?php } ?>
            </ul>
        </div>


    </div>

</div>


<?php
        echo $after_widget;
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param   array   $new_instance   Values just sent to be saved.
     * @param   array   $old_instance   Previously saved values from database.
     *
     * @uses    natalie_wp_widgets_updated_field_value()        defined in widget-fields.php
     *
     * @return  array Updated safe values to be saved.
     */
    public function update($new_instance, $old_instance) {
        $instance = $old_instance;

        $widget_fields = $this->widget_fields();

        // Loop through fields
        foreach ($widget_fields as $widget_field) {

            extract($widget_field);

            // Use helper function to get updated field values
            $instance[$natalie_widgets_name] = natalie_wp_widgets_updated_field_value($widget_field, $new_instance[$natalie_widgets_name]);
        }

        return $instance;
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param   array $instance Previously saved values from database.
     *
     * @uses    natalie_wp_widgets_show_widget_field()      defined in widget-fields.php
     */
    public function form($instance) {
        $widget_fields = $this->widget_fields();

        // Loop through fields
        foreach ($widget_fields as $widget_field) {

            // Make array elements available as variables
            extract($widget_field);
            $natalie_widgets_field_value = !empty($instance[$natalie_widgets_name]) ? esc_attr($instance[$natalie_widgets_name]) : '';
            natalie_wp_widgets_show_widget_field($this, $widget_field, $natalie_widgets_field_value);
        }
    }

}